==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZebranieZtoWykonanoKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class ZebranieZtoWykonanoKey extends GenericDPSObject {
    /**
     * ZEBRANIE_ZTO_WYKONANO.PLAN_WSPARCIA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long planWsparciaId;

    /**
     * ZEBRANIE_ZTO_WYKONANO.ZEBRANIE_ZTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zebranieZtoId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZEBRANIE_ZTO_WYKONANO.PLAN_WSPARCIA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPlanWsparciaId() {
        return planWsparciaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ZEBRANIE_ZTO_WYKONANO.PLAN_WSPARCIA_ID
     *
     * @param planWsparciaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPlanWsparciaId(Long planWsparciaId) {
        this.planWsparciaId = planWsparciaId;
    }

    /**
     * @return ZEBRANIE_ZTO_WYKONANO.ZEBRANIE_ZTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZebranieZtoId() {
        return zebranieZtoId;
    }

    /**
     * ZEBRANIE_ZTO_WYKONANO.ZEBRANIE_ZTO_ID
     *
     * @param zebranieZtoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZebranieZtoId(Long zebranieZtoId) {
        this.zebranieZtoId = zebranieZtoId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZebranieZtoWykonanoKey other = (ZebranieZtoWykonanoKey) that;
        return (this.getPlanWsparciaId() == null ? other.getPlanWsparciaId() == null : this.getPlanWsparciaId().equals(other.getPlanWsparciaId()))
            && (this.getZebranieZtoId() == null ? other.getZebranieZtoId() == null : this.getZebranieZtoId().equals(other.getZebranieZtoId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPlanWsparciaId() == null) ? 0 : getPlanWsparciaId().hashCode());
        result = prime * result + ((getZebranieZtoId() == null) ? 0 : getZebranieZtoId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", planWsparciaId=").append(planWsparciaId);
        sb.append(", zebranieZtoId=").append(zebranieZtoId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZebranieZtoWykonanoKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class ZebranieZtoWykonanoKey extends GenericDPSObject {
    /**
     * ZEBRANIE_ZTO_WYKONANO.PLAN_WSPARCIA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long planWsparciaId;

    /**
     * ZEBRANIE_ZTO_WYKONANO.ZEBRANIE_ZTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zebranieZtoId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZEBRANIE_ZTO_WYKONANO.PLAN_WSPARCIA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPlanWsparciaId() {
        return planWsparciaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ZEBRANIE_ZTO_WYKONANO.PLAN_WSPARCIA_ID
     *
     * @param planWsparciaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPlanWsparciaId(Long planWsparciaId) {
        this.planWsparciaId = planWsparciaId;
    }

    /**
     * @return ZEBRANIE_ZTO_WYKONANO.ZEBRANIE_ZTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZebranieZtoId() {
        return zebranieZtoId;
    }

    /**
     * ZEBRANIE_ZTO_WYKONANO.ZEBRANIE_ZTO_ID
     *
     * @param zebranieZtoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZebranieZtoId(Long zebranieZtoId) {
        this.zebranieZtoId = zebranieZtoId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZebranieZtoWykonanoKey other = (ZebranieZtoWykonanoKey) that;
        return (this.getPlanWsparciaId() == null ? other.getPlanWsparciaId() == null : this.getPlanWsparciaId().equals(other.getPlanWsparciaId()))
            && (this.getZebranieZtoId() == null ? other.getZebranieZtoId() == null : this.getZebranieZtoId().equals(other.getZebranieZtoId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPlanWsparciaId() == null) ? 0 : getPlanWsparciaId().hashCode());
        result = prime * result + ((getZebranieZtoId() == null) ? 0 : getZebranieZtoId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", planWsparciaId=").append(planWsparciaId);
        sb.append(", zebranieZtoId=").append(zebranieZtoId);
        sb.append("]");
        return sb.toString();
    }
}
